<?php

// Add Custom Thumbnail
add_image_size('cv-thumb', 540, 304);

function ars_register_scripts() {
    if (is_page_template('page-cv.php')) :
        // Stylesheets
        wp_enqueue_style('ars-google-fonts', 'https://fonts.googleapis.com/css?family=Montserrat:400,700,200', [], wp_get_theme()->get('Version'));
        wp_enqueue_style('ars-app-style', ARS_URI . 'assets/css/app-style.css', [], wp_get_theme()->get('Version'));
        wp_enqueue_style('ars-app-ui', ARS_URI . 'assets/css/app-ui.css', [], wp_get_theme()->get('Version'));

        // Scripts
        wp_enqueue_script('ars-app-js', ARS_URI . 'assets/js/app.js', ['jquery'], wp_get_theme()->get('Version'));

        wp_localize_script('ars-app-js', 'ajaxUrl', ['admin' => admin_url('admin-ajax.php')]);
    else :
        wp_enqueue_style('nucleare-style', get_template_directory_uri() . '/style.css', [], wp_get_theme()->get('Version'));
    endif;
}

add_action('wp_enqueue_scripts', 'ars_register_scripts');

function ars_remove_scripts() {
    if (is_page_template('page-cv.php')) :
        wp_dequeue_script('nucleare-custom');
        wp_deregister_script('nucleare-custom');
        wp_dequeue_script('nucleare-navigation');
        wp_deregister_script('nucleare-navigation');
        wp_dequeue_script('nucleare-skip-link-focus-fix');
        wp_deregister_script('nucleare-skip-link-focus-fix');
        wp_dequeue_script('bwg_frontend');
        wp_deregister_script('bwg_frontend');
    endif;
}

add_action('wp_print_scripts', 'ars_remove_scripts', 99);

function ars_remove_styles() {
    if (is_page_template('page-cv.php')) :
        wp_dequeue_style('nucleare-style');
        wp_deregister_style('nucleare-style');
        wp_dequeue_style('font-awesome');
        wp_deregister_style('font-awesome');
        wp_dequeue_style('nucleare-googlefonts');
        wp_deregister_style('nucleare-googlefonts');
        wp_dequeue_style('bwg_fonts');
        wp_deregister_style('bwg_fonts');
    endif;
}

add_action('wp_print_styles', 'ars_remove_styles', 99);

function ars_portfolio_register() {
    $labels = [
        'name'                  => _x('Portfolios', 'post type general name', 'nucleare'),
        'singular_name'         => _x('Portfolio', 'post type singular name', 'nucleare'),
        'menu_name'             => _x('Portfolios', 'admin menu', 'nucleare'),
        'name_admin_bar'        => _x('Portfolio', 'add new on admin bar', 'nucleare'),
        'add_new'               => _x('Add New', 'book', 'nucleare'),
        'add_new_item'          => __('Add New Portfolio', 'nucleare'),
        'new_item'              => __('New Portfolio', 'nucleare'),
        'edit_item'             => __('Edit Portfolio', 'nucleare'),
        'view_item'             => __('View Portfolio', 'nucleare'),
        'all_items'             => __('All Portfolios', 'nucleare'),
        'search_items'          => __('Search Portfolios', 'nucleare'),
        'parent_item_colon'     => __('Parent Portfolios:', 'nucleare'),
        'not_found'             => __('No books found.', 'nucleare'),
        'not_found_in_trash'    => __('No books found in Trash.', 'nucleare')
    ];

    $args = [
        'labels'                => $labels,
        'public'                => true,
        'publicly_queryable'    => true,
        'show_ui'               => true,
        'show_in_menu'          => true,
        'query_var'             => true,
        'rewrite'               => ['slug' => 'portfolio'],
        'capability_type'       => 'page',
        'has_archive'           => true,
        'hierarchical'          => false,
        'menu_position'         => 20,
        'menu_icon'             => 'dashicons-category',
        'supports'              => ['title', 'editor', 'author', 'thumbnail', 'excerpt', 'comments'],
        'show_in_rest'          => true, // Gutenberg Support
    ];

    register_post_type('portfolio', $args);
}

add_action('init', 'ars_portfolio_register');

function ars_portfolio_taxonomy_register() {
    $labels = [
        'name'              => _x('Portfolio Categories', 'taxonomy general name', 'nucleare'),
        'singular_name'     => _x('Portfolio Category', 'taxonomy singular name', 'nucleare'),
        'search_items'      => __('Search Portfolio Categories', 'nucleare'),
        'all_items'         => __('All Portfolio Categories', 'nucleare'),
        'parent_item'       => __('Parent Portfolio Category', 'nucleare'),
        'parent_item_colon' => __('Parent Portfolio Category:', 'nucleare'),
        'edit_item'         => __('Edit Portfolio Category', 'nucleare'),
        'update_item'       => __('Update Portfolio Category', 'nucleare'),
        'add_new_item'      => __('Add New Portfolio Category', 'nucleare'),
        'new_item_name'     => __('New Portfolio Category Name', 'nucleare'),
        'menu_name'         => __('Categories', 'nucleare'),
    ];

    $args = [
        'hierarchical'      => true,
        'labels'            => $labels,
        'show_ui'           => true,
        'show_admin_column' => true,
        'query_var'         => true,
        'rewrite'           => ['slug' => 'portfolio-category'],
        'show_in_rest'      => true,
        'show_in_nav_menus' => false,
    ];

    register_taxonomy('portfolio_category', ['portfolio'], $args);

    $labels = [
        'name'              => _x('Portfolio Tags', 'taxonomy general name', 'nucleare'),
        'singular_name'     => _x('Portfolio Tag', 'taxonomy singular name', 'nucleare'),
        'search_items'      => __('Search Portfolio Tags', 'nucleare'),
        'all_items'         => __('All Portfolio Tags', 'nucleare'),
        'parent_item'       => __('Parent Portfolio Tag', 'nucleare'),
        'parent_item_colon' => __('Parent Portfolio Tag:', 'nucleare'),
        'edit_item'         => __('Edit Portfolio Tag', 'nucleare'),
        'update_item'       => __('Update Portfolio Tag', 'nucleare'),
        'add_new_item'      => __('Add New Portfolio Tag', 'nucleare'),
        'new_item_name'     => __('New Portfolio Tag Name', 'nucleare'),
        'menu_name'         => __('Tags', 'nucleare'),
    ];

    $args = [
        'labels'            => $labels,
        'show_ui'           => true,
        'show_admin_column' => true,
        'query_var'         => true,
        'rewrite'           => ['slug' => 'portfolio-tag'],
        'show_in_rest'      => true,
        'show_in_nav_menus' => false
    ];

    register_taxonomy('portfolio_tag', ['portfolio'], $args);
}

add_action('init', 'ars_portfolio_taxonomy_register', 0);

function ars_register_nav_menu() {
    register_nav_menu('cv-menu', __('CV Page Menu', 'nucleare'));
}

add_action('after_setup_theme', 'ars_register_nav_menu');

function ars_cv_menu_classes($classes, $item, $args) {
    if ($args->theme_location == 'cv-menu') :
        array_unshift($classes, 'nav-item');
    endif;

    return $classes;
}

add_filter('nav_menu_css_class', 'ars_cv_menu_classes', 1, 3);

function ars_cv_menu_link($atts, $item, $args) {
    if ($args->theme_location == 'cv-menu') :
        $atts['class'] = "nav-link smooth-scroll";
    endif;

    return $atts;
}

add_filter('nav_menu_link_attributes', 'ars_cv_menu_link', 10, 3);